# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/v0/environments/configuration.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.administration.runtime_configuration.v0 import runtime_config_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_runtime__config__pb2
from _qwak_proto.qwak.administration.runtime_configuration.v0 import network_config_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_network__config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7qwak/administration/v0/environments/configuration.proto\x12\x1fqwak.administration.environment\x1a\x41qwak/administration/runtime_configuration/v0/runtime_config.proto\x1a\x41qwak/administration/runtime_configuration/v0/network_config.proto\"\xfe\x04\n\x1cQwakEnvironmentConfiguration\x12\x19\n\x11\x65\x64ge_services_url\x18\x01 \x01(\t\x12\x1d\n\x15management_access_url\x18\x06 \x01(\t\x12\x15\n\rmodel_api_url\x18\x02 \x01(\t\x12\x1e\n\x16\x61nalytics_data_api_url\x18\x03 \x01(\t\x12\x1d\n\x15object_storage_bucket\x18\x04 \x01(\t\x12\x19\n\x11\x62i_system_api_key\x18\x05 \x01(\t\x12T\n\x13\x63loud_configuration\x18\x07 \x01(\x0b\x32\x37.qwak.administration.environment.QwakCloudConfiguration\x12_\n\x1b\x66\x65\x61ture_store_configuration\x18\x08 \x01(\x0b\x32:.qwak.administration.environment.FeatureStoreConfiguration\x12!\n\x19\x63ontainer_registry_prefix\x18\t \x01(\t\x12]\n\x1a\x63ommunication_manager_type\x18\n \x01(\x0e\x32\x39.qwak.administration.environment.CommunicationManagerType\x12_\n\x1a\x65nvironment_runtime_config\x18\x0b \x01(\x0b\x32\x39.qwak.administration.environment.EnvironmentRuntimeConfigH\x00\x42\x19\n\x17optional_runtime_config\"v\n\x19\x46\x65\x61tureStoreConfiguration\x12\x1d\n\x15\x61irflow_connection_id\x18\x01 \x01(\t\x12\x15\n\rredis_address\x18\x02 \x01(\t\x12#\n\x1buser_code_execution_allowed\x18\x03 \x01(\x08\"\xdf\x01\n\x16QwakCloudConfiguration\x12Y\n\x17\x61ws_cloud_configuration\x18\x01 \x01(\x0b\x32\x36.qwak.administration.environment.AwsCloudConfigurationH\x00\x12Y\n\x17gcp_cloud_configuration\x18\x02 \x01(\x0b\x32\x36.qwak.administration.environment.GcpCloudConfigurationH\x00\x42\x0f\n\rconfiguration\"\xae\x01\n\x15\x41wsCloudConfiguration\x12\x0e\n\x06region\x18\x01 \x01(\t\x12\x10\n\x08role_arn\x18\x02 \x01(\t\x12K\n\x11\x66\x65\x61ture_store_emr\x18\x03 \x01(\x0b\x32\x30.qwak.administration.environment.FeatureStoreEmr\x12\x13\n\x0b\x65xternal_id\x18\x04 \x01(\t\x12\x11\n\tworkgroup\x18\x05 \x01(\t\"\xb0\x01\n\x15GcpCloudConfiguration\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x0e\n\x06region\x18\x02 \x01(\t\x12 \n\x18\x62ig_lake_connection_name\x18\x03 \x01(\t\x12\x19\n\x11\x62ig_lake_location\x18\x04 \x01(\t\x12\x17\n\x0fservice_account\x18\x05 \x01(\t\x12\x1d\n\x15\x62ig_lake_catalog_name\x18\x06 \x01(\t\"\xc5\x01\n\x0f\x46\x65\x61tureStoreEmr\x12\x14\n\x0c\x65\x63\x32_key_name\x18\x01 \x01(\t\x12\x15\n\rec2_subnet_id\x18\x02 \x01(\t\x12\x19\n\x11\x65mr_job_flow_role\x18\x03 \x01(\t\x12\x18\n\x10\x65mr_service_role\x18\x04 \x01(\t\x12%\n\x1d\x65\x63\x32_additional_security_group\x18\x05 \x01(\t\x12)\n!target_on_demand_capacity_workers\x18\x06 \x01(\x05\"\xfa\x01\n\x18\x45nvironmentRuntimeConfig\x12\x61\n\x15runtime_configuration\x18\x01 \x01(\x0b\x32\x42.qwak.administration.runtime_configuration.v0.RuntimeConfiguration\x12{\n\x15network_configuration\x18\x02 \x01(\x0b\x32\\.qwak.administration.runtime_configuration.v0.network_config.EnvironmentNetworkConfiguration*X\n\x18\x43ommunicationManagerType\x12\x13\n\x0fINVALID_MANAGER\x10\x00\x12\x12\n\x0e\x44IRECT_MANAGER\x10\x01\x12\x13\n\x0f\x41\x44MIRAL_MANAGER\x10\x02\x42\xb2\x01\n\x1e\x63om.qwak.ai.administration.apiP\x01Z\x8d\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/v0/environments;environment_v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.administration.v0.environments.configuration_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036com.qwak.ai.administration.apiP\001Z\215\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/v0/environments;environment_v0'
  _globals['_COMMUNICATIONMANAGERTYPE']._serialized_start=2022
  _globals['_COMMUNICATIONMANAGERTYPE']._serialized_end=2110
  _globals['_QWAKENVIRONMENTCONFIGURATION']._serialized_start=227
  _globals['_QWAKENVIRONMENTCONFIGURATION']._serialized_end=865
  _globals['_FEATURESTORECONFIGURATION']._serialized_start=867
  _globals['_FEATURESTORECONFIGURATION']._serialized_end=985
  _globals['_QWAKCLOUDCONFIGURATION']._serialized_start=988
  _globals['_QWAKCLOUDCONFIGURATION']._serialized_end=1211
  _globals['_AWSCLOUDCONFIGURATION']._serialized_start=1214
  _globals['_AWSCLOUDCONFIGURATION']._serialized_end=1388
  _globals['_GCPCLOUDCONFIGURATION']._serialized_start=1391
  _globals['_GCPCLOUDCONFIGURATION']._serialized_end=1567
  _globals['_FEATURESTOREEMR']._serialized_start=1570
  _globals['_FEATURESTOREEMR']._serialized_end=1767
  _globals['_ENVIRONMENTRUNTIMECONFIG']._serialized_start=1770
  _globals['_ENVIRONMENTRUNTIMECONFIG']._serialized_end=2020
# @@protoc_insertion_point(module_scope)
