# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/automation/v1/automation_management_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.automation.v1 import automation_pb2 as qwak_dot_automation_dot_v1_dot_automation__pb2
from _qwak_proto.qwak.automation.v1 import automation_execution_pb2 as qwak_dot_automation_dot_v1_dot_automation__execution__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6qwak/automation/v1/automation_management_service.proto\x12\x12qwak.automation.v1\x1a#qwak/automation/v1/automation.proto\x1a-qwak/automation/v1/automation_execution.proto\"V\n\x17\x43reateAutomationRequest\x12;\n\x0f\x61utomation_spec\x18\x01 \x01(\x0b\x32\".qwak.automation.v1.AutomationSpec\"1\n\x18\x43reateAutomationResponse\x12\x15\n\rautomation_id\x18\x01 \x01(\t\"m\n\x17UpdateAutomationRequest\x12\x15\n\rautomation_id\x18\x01 \x01(\t\x12;\n\x0f\x61utomation_spec\x18\x02 \x01(\x0b\x32\".qwak.automation.v1.AutomationSpec\"\x1a\n\x18UpdateAutomationResponse\"0\n\x17\x44\x65leteAutomationRequest\x12\x15\n\rautomation_id\x18\x01 \x01(\t\"\x1a\n\x18\x44\x65leteAutomationResponse\"*\n\x16ListAutomationsRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\"N\n\x17ListAutomationsResponse\x12\x33\n\x0b\x61utomations\x18\x01 \x03(\x0b\x32\x1e.qwak.automation.v1.Automation\"-\n\x14GetAutomationRequest\x12\x15\n\rautomation_id\x18\x01 \x01(\t\"K\n\x15GetAutomationResponse\x12\x32\n\nautomation\x18\x01 \x01(\x0b\x32\x1e.qwak.automation.v1.Automation\"5\n\x1aGetAutomationByNameRequest\x12\x17\n\x0f\x61utomation_name\x18\x01 \x01(\t\"Q\n\x1bGetAutomationByNameResponse\x12\x32\n\nautomation\x18\x01 \x01(\x0b\x32\x1e.qwak.automation.v1.Automation\"k\n\x1fListAutomationExecutionsRequest\x12\x15\n\rautomation_id\x18\x01 \x01(\t\x12\x31\n\ndate_range\x18\x02 \x01(\x0b\x32\x1d.qwak.automation.v1.DateRange\"q\n ListAutomationExecutionsResponse\x12M\n\x15\x61utomation_executions\x18\x01 \x03(\x0b\x32..qwak.automation.v1.AutomationExecutionMessage\"7\n#ListLastAutomationExecutionsRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\"\xbe\x02\n$ListLastAutomationExecutionsResponse\x12\x97\x01\n*last_automation_execution_by_automation_id\x18\x01 \x03(\x0b\x32\x63.qwak.automation.v1.ListLastAutomationExecutionsResponse.LastAutomationExecutionByAutomationIdEntry\x1a|\n*LastAutomationExecutionByAutomationIdEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12=\n\x05value\x18\x02 \x01(\x0b\x32..qwak.automation.v1.AutomationExecutionMessage:\x02\x38\x01\"Q\n\"RegisterAutomationExecutionRequest\x12\x15\n\rautomation_id\x18\x01 \x01(\t\x12\x14\n\x0c\x65xecution_id\x18\x02 \x01(\t\"%\n#RegisterAutomationExecutionResponse\"}\n UpdateAutomationExecutionRequest\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\x12\x43\n\x0brun_details\x18\x02 \x01(\x0b\x32..qwak.automation.v1.ExecutionRunDetailsMessage\"#\n!UpdateAutomationExecutionResponse\"L\n\x1fToggleAutomationActivityRequest\x12\x15\n\rautomation_id\x18\x01 \x01(\t\x12\x12\n\nis_enabled\x18\x02 \x01(\x08\"\"\n ToggleAutomationActivityResponse\"-\n\x14RunAutomationRequest\x12\x15\n\rautomation_id\x18\x01 \x01(\t\"\x17\n\x15RunAutomationResponse2\xda\x0b\n\x1b\x41utomationManagementService\x12m\n\x10\x43reateAutomation\x12+.qwak.automation.v1.CreateAutomationRequest\x1a,.qwak.automation.v1.CreateAutomationResponse\x12m\n\x10UpdateAutomation\x12+.qwak.automation.v1.UpdateAutomationRequest\x1a,.qwak.automation.v1.UpdateAutomationResponse\x12m\n\x10\x44\x65leteAutomation\x12+.qwak.automation.v1.DeleteAutomationRequest\x1a,.qwak.automation.v1.DeleteAutomationResponse\x12\x64\n\rGetAutomation\x12(.qwak.automation.v1.GetAutomationRequest\x1a).qwak.automation.v1.GetAutomationResponse\x12v\n\x13GetAutomationByName\x12..qwak.automation.v1.GetAutomationByNameRequest\x1a/.qwak.automation.v1.GetAutomationByNameResponse\x12j\n\x0fListAutomations\x12*.qwak.automation.v1.ListAutomationsRequest\x1a+.qwak.automation.v1.ListAutomationsResponse\x12\x85\x01\n\x18ListAutomationExecutions\x12\x33.qwak.automation.v1.ListAutomationExecutionsRequest\x1a\x34.qwak.automation.v1.ListAutomationExecutionsResponse\x12\x91\x01\n\x1cListLastAutomationExecutions\x12\x37.qwak.automation.v1.ListLastAutomationExecutionsRequest\x1a\x38.qwak.automation.v1.ListLastAutomationExecutionsResponse\x12\x8e\x01\n\x1bRegisterAutomationExecution\x12\x36.qwak.automation.v1.RegisterAutomationExecutionRequest\x1a\x37.qwak.automation.v1.RegisterAutomationExecutionResponse\x12\x88\x01\n\x19UpdateAutomationExecution\x12\x34.qwak.automation.v1.UpdateAutomationExecutionRequest\x1a\x35.qwak.automation.v1.UpdateAutomationExecutionResponse\x12\x85\x01\n\x18ToggleAutomationActivity\x12\x33.qwak.automation.v1.ToggleAutomationActivityRequest\x1a\x34.qwak.automation.v1.ToggleAutomationActivityResponse\x12\x64\n\rRunAutomation\x12(.qwak.automation.v1.RunAutomationRequest\x1a).qwak.automation.v1.RunAutomationResponseB!\n\x1d\x63om.qwak.ai.automation.api.v1P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.automation.v1.automation_management_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.qwak.ai.automation.api.v1P\001'
  _LISTLASTAUTOMATIONEXECUTIONSRESPONSE_LASTAUTOMATIONEXECUTIONBYAUTOMATIONIDENTRY._options = None
  _LISTLASTAUTOMATIONEXECUTIONSRESPONSE_LASTAUTOMATIONEXECUTIONBYAUTOMATIONIDENTRY._serialized_options = b'8\001'
  _globals['_CREATEAUTOMATIONREQUEST']._serialized_start=162
  _globals['_CREATEAUTOMATIONREQUEST']._serialized_end=248
  _globals['_CREATEAUTOMATIONRESPONSE']._serialized_start=250
  _globals['_CREATEAUTOMATIONRESPONSE']._serialized_end=299
  _globals['_UPDATEAUTOMATIONREQUEST']._serialized_start=301
  _globals['_UPDATEAUTOMATIONREQUEST']._serialized_end=410
  _globals['_UPDATEAUTOMATIONRESPONSE']._serialized_start=412
  _globals['_UPDATEAUTOMATIONRESPONSE']._serialized_end=438
  _globals['_DELETEAUTOMATIONREQUEST']._serialized_start=440
  _globals['_DELETEAUTOMATIONREQUEST']._serialized_end=488
  _globals['_DELETEAUTOMATIONRESPONSE']._serialized_start=490
  _globals['_DELETEAUTOMATIONRESPONSE']._serialized_end=516
  _globals['_LISTAUTOMATIONSREQUEST']._serialized_start=518
  _globals['_LISTAUTOMATIONSREQUEST']._serialized_end=560
  _globals['_LISTAUTOMATIONSRESPONSE']._serialized_start=562
  _globals['_LISTAUTOMATIONSRESPONSE']._serialized_end=640
  _globals['_GETAUTOMATIONREQUEST']._serialized_start=642
  _globals['_GETAUTOMATIONREQUEST']._serialized_end=687
  _globals['_GETAUTOMATIONRESPONSE']._serialized_start=689
  _globals['_GETAUTOMATIONRESPONSE']._serialized_end=764
  _globals['_GETAUTOMATIONBYNAMEREQUEST']._serialized_start=766
  _globals['_GETAUTOMATIONBYNAMEREQUEST']._serialized_end=819
  _globals['_GETAUTOMATIONBYNAMERESPONSE']._serialized_start=821
  _globals['_GETAUTOMATIONBYNAMERESPONSE']._serialized_end=902
  _globals['_LISTAUTOMATIONEXECUTIONSREQUEST']._serialized_start=904
  _globals['_LISTAUTOMATIONEXECUTIONSREQUEST']._serialized_end=1011
  _globals['_LISTAUTOMATIONEXECUTIONSRESPONSE']._serialized_start=1013
  _globals['_LISTAUTOMATIONEXECUTIONSRESPONSE']._serialized_end=1126
  _globals['_LISTLASTAUTOMATIONEXECUTIONSREQUEST']._serialized_start=1128
  _globals['_LISTLASTAUTOMATIONEXECUTIONSREQUEST']._serialized_end=1183
  _globals['_LISTLASTAUTOMATIONEXECUTIONSRESPONSE']._serialized_start=1186
  _globals['_LISTLASTAUTOMATIONEXECUTIONSRESPONSE']._serialized_end=1504
  _globals['_LISTLASTAUTOMATIONEXECUTIONSRESPONSE_LASTAUTOMATIONEXECUTIONBYAUTOMATIONIDENTRY']._serialized_start=1380
  _globals['_LISTLASTAUTOMATIONEXECUTIONSRESPONSE_LASTAUTOMATIONEXECUTIONBYAUTOMATIONIDENTRY']._serialized_end=1504
  _globals['_REGISTERAUTOMATIONEXECUTIONREQUEST']._serialized_start=1506
  _globals['_REGISTERAUTOMATIONEXECUTIONREQUEST']._serialized_end=1587
  _globals['_REGISTERAUTOMATIONEXECUTIONRESPONSE']._serialized_start=1589
  _globals['_REGISTERAUTOMATIONEXECUTIONRESPONSE']._serialized_end=1626
  _globals['_UPDATEAUTOMATIONEXECUTIONREQUEST']._serialized_start=1628
  _globals['_UPDATEAUTOMATIONEXECUTIONREQUEST']._serialized_end=1753
  _globals['_UPDATEAUTOMATIONEXECUTIONRESPONSE']._serialized_start=1755
  _globals['_UPDATEAUTOMATIONEXECUTIONRESPONSE']._serialized_end=1790
  _globals['_TOGGLEAUTOMATIONACTIVITYREQUEST']._serialized_start=1792
  _globals['_TOGGLEAUTOMATIONACTIVITYREQUEST']._serialized_end=1868
  _globals['_TOGGLEAUTOMATIONACTIVITYRESPONSE']._serialized_start=1870
  _globals['_TOGGLEAUTOMATIONACTIVITYRESPONSE']._serialized_end=1904
  _globals['_RUNAUTOMATIONREQUEST']._serialized_start=1906
  _globals['_RUNAUTOMATIONREQUEST']._serialized_end=1951
  _globals['_RUNAUTOMATIONRESPONSE']._serialized_start=1953
  _globals['_RUNAUTOMATIONRESPONSE']._serialized_end=1976
  _globals['_AUTOMATIONMANAGEMENTSERVICE']._serialized_start=1979
  _globals['_AUTOMATIONMANAGEMENTSERVICE']._serialized_end=3477
# @@protoc_insertion_point(module_scope)
