# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/workspace/workspace.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.user_application.common.v0 import resources_pb2 as qwak_dot_user__application_dot_common_dot_v0_dot_resources__pb2
from _qwak_proto.qwak.user_application.v0 import user_application_pb2 as qwak_dot_user__application_dot_v0_dot_user__application__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eqwak/workspace/workspace.proto\x12\x19qwak.workspace.management\x1a\x1fgoogle/protobuf/timestamp.proto\x1a/qwak/user_application/common/v0/resources.proto\x1a/qwak/user_application/v0/user_application.proto\"\xc4\x04\n\tWorkspace\x12\x16\n\x0eworkspace_name\x18\x01 \x01(\t\x12`\n\x1c\x63lient_pod_compute_resources\x18\x02 \x01(\x0b\x32:.qwak.user_application.common.v0.ClientPodComputeResources\x12\x10\n\x08image_id\x18\x03 \x01(\t\x12\x17\n\x0f\x63reator_user_id\x18\x04 \x01(\t\x12\x1b\n\x13last_update_user_id\x18\x05 \x01(\t\x12/\n\x0b\x63reate_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10last_update_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0cworkspace_id\x18\t \x01(\t\x12\x0c\n\x04tags\x18\n \x03(\t\x12N\n\x1aworkspace_deployment_state\x18\x0b \x01(\x0e\x32*.qwak.workspace.management.DeploymentState\x12\x44\n\x10workspace_status\x18\x0c \x01(\x0e\x32*.qwak.workspace.management.WorkspaceStatus\x12\x15\n\rerror_message\x18\r \x01(\t\x12\x12\n\nimage_name\x18\x0e \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x0f \x01(\t\x12\x11\n\tbuild_ids\x18\x10 \x03(\t\"\xd3\x01\n\rWorkspaceSpec\x12\x16\n\x0eworkspace_name\x18\x01 \x01(\t\x12`\n\x1c\x63lient_pod_compute_resources\x18\x02 \x01(\x0b\x32:.qwak.user_application.common.v0.ClientPodComputeResources\x12\x10\n\x08image_id\x18\x03 \x01(\t\x12\x0c\n\x04tags\x18\x04 \x03(\t\x12\x16\n\x0e\x65nvironment_id\x18\x05 \x01(\t\x12\x10\n\x08\x62uild_id\x18\x06 \x01(\t\"\x9d\x02\n\x1bWorkspaceDeploymentSnapshot\x12\x16\n\x0eworkspace_name\x18\x01 \x01(\t\x12\x14\n\x0cworkspace_id\x18\x02 \x01(\t\x12\x36\n\ndeployment\x18\x03 \x01(\x0b\x32\x1e.qwak.user_application.v0.SpecB\x02\x18\x01\x12\x34\n\x08replicas\x18\x04 \x03(\x0b\x32\x1e.qwak.user_application.v0.SpecB\x02\x18\x01\x12,\n\x04pods\x18\x05 \x03(\x0b\x32\x1e.qwak.user_application.v0.Spec\x12\x34\n\x0cstateful_set\x18\x06 \x01(\x0b\x32\x1e.qwak.user_application.v0.Spec\"\xb1\x01\n$UpdateWorkspaceStatusFromEdgeDetails\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x02 \x01(\t\x12]\n\x1dworkspace_deployment_snapshot\x18\x03 \x03(\x0b\x32\x36.qwak.workspace.management.WorkspaceDeploymentSnapshot\"Y\n\x0eWorkspaceImage\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12-\n\x04type\x18\x03 \x01(\x0e\x32\x1f.qwak.workspace.management.Type\"\xfb\x01\n\x17\x44\x65\x66\x61ultWorkspaceDetails\x12Y\n\x15\x63pu_compute_resources\x18\x01 \x01(\x0b\x32:.qwak.user_application.common.v0.ClientPodComputeResources\x12Y\n\x15gpu_compute_resources\x18\x02 \x01(\x0b\x32:.qwak.user_application.common.v0.ClientPodComputeResources\x12\x14\n\x0c\x63pu_image_id\x18\x03 \x01(\t\x12\x14\n\x0cgpu_image_id\x18\x04 \x01(\t*\x18\n\x04Type\x12\x07\n\x03\x43PU\x10\x00\x12\x07\n\x03GPU\x10\x01*\xaa\x01\n\x0fWorkspaceStatus\x12\x1c\n\x18WORKSPACE_STATUS_UNKNOWN\x10\x00\x12!\n\x1dWORKSPACE_STATUS_INITIALIZING\x10\x01\x12\x1c\n\x18WORKSPACE_STATUS_STARTED\x10\x02\x12\x1c\n\x18WORKSPACE_STATUS_STOPPED\x10\x03\x12\x1a\n\x16WORKSPACE_STATUS_ERROR\x10\x04*\xe0\x07\n\x0f\x44\x65ploymentState\x12\x1c\n\x18\x44\x45PLOYMENT_STATE_UNKNOWN\x10\x00\x12)\n%DEPLOYMENT_STATE_INITIATING_WORKSPACE\x10\x01\x12\x30\n,DEPLOYMENT_STATE_DEPLOYING_REQUEST_WORKSPACE\x10\x02\x12\x33\n/DEPLOYMENT_STATE_FAILED_EVENT_COMMAND_WORKSPACE\x10\x03\x12)\n%DEPLOYMENT_STATE_DELETION_IN_PROGRESS\x10\x04\x12\x33\n/DEPLOYMENT_STATE_RESUME_EVENT_COMMAND_WORKSPACE\x10\x05\x12\x31\n-DEPLOYMENT_STATE_STOP_EVENT_COMMAND_WORKSPACE\x10\x06\x12(\n$DEPLOYMENT_STATE_STOPPING_DEPLOYMENT\x10\x07\x12\'\n#DEPLOYMENT_STATE_STOPPED_DEPLOYMENT\x10\x08\x12 \n\x1c\x44\x45PLOYMENT_STATE_INITIALIZED\x10\t\x12\x1a\n\x16\x44\x45PLOYMENT_STATE_READY\x10\n\x12%\n!DEPLOYMENT_STATE_CONTAINERS_READY\x10\x0b\x12\"\n\x1e\x44\x45PLOYMENT_STATE_POD_SCHEDULED\x10\x0c\x12\"\n\x1e\x44\x45PLOYMENT_STATE_UNSCHEDULABLE\x10\r\x12)\n%DEPLOYMENT_STATE_CONTAINERS_NOT_READY\x10\x0e\x12\x1e\n\x1a\x44\x45PLOYMENT_STATE_AVAILABLE\x10\x0f\x12 \n\x1c\x44\x45PLOYMENT_STATE_PROGRESSING\x10\x10\x12$\n DEPLOYMENT_STATE_REPLICA_FAILURE\x10\x11\x12/\n+DEPLOYMENT_STATE_MINIMUM_REPLICAS_AVAILABLE\x10\x12\x12\x31\n-DEPLOYMENT_STATE_MINIMUM_REPLICAS_UNAVAILABLE\x10\x13\x12\x30\n,DEPLOYMENT_STATE_PROGRESS_DEAD_LINE_EXCEEDED\x10\x14\x12.\n*DEPLOYMENT_STATE_NEW_REPLICA_SET_AVAILABLE\x10\x15\x12\x31\n-DEPLOYMENT_STATE_IDLE_TIME_STOPPED_DEPLOYMENT\x10\x16\x42\x42\n$com.qwak.ai.management.workspace.apiP\x01Z\x18qwak/workspace;workspaceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.workspace.workspace_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$com.qwak.ai.management.workspace.apiP\001Z\030qwak/workspace;workspace'
  _WORKSPACEDEPLOYMENTSNAPSHOT.fields_by_name['deployment']._options = None
  _WORKSPACEDEPLOYMENTSNAPSHOT.fields_by_name['deployment']._serialized_options = b'\030\001'
  _WORKSPACEDEPLOYMENTSNAPSHOT.fields_by_name['replicas']._options = None
  _WORKSPACEDEPLOYMENTSNAPSHOT.fields_by_name['replicas']._serialized_options = b'\030\001'
  _globals['_TYPE']._serialized_start=1802
  _globals['_TYPE']._serialized_end=1826
  _globals['_WORKSPACESTATUS']._serialized_start=1829
  _globals['_WORKSPACESTATUS']._serialized_end=1999
  _globals['_DEPLOYMENTSTATE']._serialized_start=2002
  _globals['_DEPLOYMENTSTATE']._serialized_end=2994
  _globals['_WORKSPACE']._serialized_start=193
  _globals['_WORKSPACE']._serialized_end=773
  _globals['_WORKSPACESPEC']._serialized_start=776
  _globals['_WORKSPACESPEC']._serialized_end=987
  _globals['_WORKSPACEDEPLOYMENTSNAPSHOT']._serialized_start=990
  _globals['_WORKSPACEDEPLOYMENTSNAPSHOT']._serialized_end=1275
  _globals['_UPDATEWORKSPACESTATUSFROMEDGEDETAILS']._serialized_start=1278
  _globals['_UPDATEWORKSPACESTATUSFROMEDGEDETAILS']._serialized_end=1455
  _globals['_WORKSPACEIMAGE']._serialized_start=1457
  _globals['_WORKSPACEIMAGE']._serialized_end=1546
  _globals['_DEFAULTWORKSPACEDETAILS']._serialized_start=1549
  _globals['_DEFAULTWORKSPACEDETAILS']._serialized_end=1800
# @@protoc_insertion_point(module_scope)
