# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/execution/v1/state/spark_execution_state.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3qwak/execution/v1/state/spark_execution_state.proto\x12%qwak.feature.store.execution.v1.state\"\x8f\x03\n\x13SparkExecutionState\x12\x16\n\x0e\x61pplication_id\x18\x01 \x01(\t\x12S\n\x16spark_application_type\x18\x02 \x01(\x0e\x32\x33.qwak.feature.store.execution.v1.state.SparkAppType\x12O\n\x0fspark_app_state\x18\x03 \x01(\x0b\x32\x34.qwak.feature.store.execution.v1.state.SparkAppStateH\x00\x12l\n\x11\x61pplicationLabels\x18\x04 \x03(\x0b\x32Q.qwak.feature.store.execution.v1.state.SparkExecutionState.ApplicationLabelsEntry\x1a\x38\n\x16\x41pplicationLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x12\n\x10state_descriptor\"t\n\rSparkAppState\x12L\n\nstate_type\x18\x01 \x01(\x0e\x32\x38.qwak.feature.store.execution.v1.state.SparkAppStateType\x12\x15\n\rerror_message\x18\x02 \x01(\t*\xdf\x03\n\x0cSparkAppType\x12\x1a\n\x16SPARK_APP_TYPE_INVALID\x10\x00\x12\"\n\x1eSPARK_APP_TYPE_BATCH_INGESTION\x10\x01\x12!\n\x1dSPARK_APP_TYPE_BATCH_BACKFILL\x10\x02\x12!\n\x1dSPARK_APP_TYPE_BATCH_DELETION\x10\x03\x12#\n\x1fSPARK_APP_TYPE_STREAMING_ONLINE\x10\x04\x12$\n SPARK_APP_TYPE_STREAMING_OFFLINE\x10\x05\x12%\n!SPARK_APP_TYPE_STREAMING_BACKFILL\x10\x06\x12%\n!SPARK_APP_TYPE_STREAMING_DELETION\x10\x07\x12*\n&SPARK_APP_TYPE_STREAMING_AGGR_ROWLEVEL\x10\x08\x12,\n(SPARK_APP_TYPE_STREAMING_AGGR_COMPACTION\x10\t\x12*\n&SPARK_APP_TYPE_STREAMING_AGGR_BACKFILL\x10\n\x12*\n&SPARK_APP_TYPE_STREAMING_AGGR_DELETION\x10\x0b*\x88\x03\n\x11SparkAppStateType\x12\x1b\n\x17SPARK_APP_STATE_INVALID\x10\x00\x12\x1d\n\x19SPARK_APP_STATE_COMPLETED\x10\x01\x12\x1a\n\x16SPARK_APP_STATE_FAILED\x10\x02\x12%\n!SPARK_APP_STATE_SUBMISSION_FAILED\x10\x03\x12\x1b\n\x17SPARK_APP_STATE_FAILING\x10\x04\x12 \n\x1cSPARK_APP_STATE_INVALIDATING\x10\x05\x12\x19\n\x15SPARK_APP_STATE_EMPTY\x10\x06\x12!\n\x1dSPARK_APP_STATE_PENDING_RERUN\x10\x07\x12\x1b\n\x17SPARK_APP_STATE_RUNNING\x10\x08\x12\x1d\n\x19SPARK_APP_STATE_SUBMITTED\x10\t\x12\x1e\n\x1aSPARK_APP_STATE_SUCCEEDING\x10\n\x12\x1b\n\x17SPARK_APP_STATE_UNKNOWN\x10\x0b\x42`\n+com.qwak.ai.features.execution.api.v1.stateP\x01Z/qwak/execution_management/state;execution_stateb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.execution.v1.state.spark_execution_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n+com.qwak.ai.features.execution.api.v1.stateP\001Z/qwak/execution_management/state;execution_state'
  _SPARKEXECUTIONSTATE_APPLICATIONLABELSENTRY._options = None
  _SPARKEXECUTIONSTATE_APPLICATIONLABELSENTRY._serialized_options = b'8\001'
  _globals['_SPARKAPPTYPE']._serialized_start=615
  _globals['_SPARKAPPTYPE']._serialized_end=1094
  _globals['_SPARKAPPSTATETYPE']._serialized_start=1097
  _globals['_SPARKAPPSTATETYPE']._serialized_end=1489
  _globals['_SPARKEXECUTIONSTATE']._serialized_start=95
  _globals['_SPARKEXECUTIONSTATE']._serialized_end=494
  _globals['_SPARKEXECUTIONSTATE_APPLICATIONLABELSENTRY']._serialized_start=418
  _globals['_SPARKEXECUTIONSTATE_APPLICATIONLABELSENTRY']._serialized_end=474
  _globals['_SPARKAPPSTATE']._serialized_start=496
  _globals['_SPARKAPPSTATE']._serialized_end=612
# @@protoc_insertion_point(module_scope)
