# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/runtime_configuration/v0/external/victoriametrics_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.administration.runtime_configuration.v0.external import prometheus_config_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_external_dot_prometheus__config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRqwak/administration/runtime_configuration/v0/external/victoriametrics_config.proto\x12Lqwak.administration.runtime_configuration.v0.external.victoriametrics_config\x1aMqwak/administration/runtime_configuration/v0/external/prometheus_config.proto\"\x9c\x01\n\x1cVictoriaMetricsConfiguration\x12n\n\x06promxy\x18\x01 \x01(\x0b\x32\\.qwak.administration.runtime_configuration.v0.external.prometheus_config.PromxyConfigurationH\x00\x42\x0c\n\nproxy_typeB\xfe\x01\nEcom.jfrog.ml.runtime_configuration.v0.external.victoriametrics_configP\x01Z\xb2\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0/external;runtime_configuration_v0_externalb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.administration.runtime_configuration.v0.external.victoriametrics_config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nEcom.jfrog.ml.runtime_configuration.v0.external.victoriametrics_configP\001Z\262\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0/external;runtime_configuration_v0_external'
  _globals['_VICTORIAMETRICSCONFIGURATION']._serialized_start=244
  _globals['_VICTORIAMETRICSCONFIGURATION']._serialized_end=400
# @@protoc_insertion_point(module_scope)
