# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.admiral.user_application_instance.v0 import user_application_instance_service_pb2 as qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2


class UserApplicationInstanceServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateUserApplicationInstance = channel.unary_unary(
                '/qwak.admiral.user_app_instance.v0.UserApplicationInstanceService/CreateUserApplicationInstance',
                request_serializer=qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.CreateUserApplicationInstanceRequest.SerializeToString,
                response_deserializer=qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.CreateUserApplicationInstanceResponse.FromString,
                )
        self.UpdateUserApplicationInstanceSpec = channel.unary_unary(
                '/qwak.admiral.user_app_instance.v0.UserApplicationInstanceService/UpdateUserApplicationInstanceSpec',
                request_serializer=qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.UpdateUserApplicationInstanceSpecRequest.SerializeToString,
                response_deserializer=qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.UpdateUserApplicationInstanceSpecResponse.FromString,
                )
        self.GetUserApplicationInstance = channel.unary_unary(
                '/qwak.admiral.user_app_instance.v0.UserApplicationInstanceService/GetUserApplicationInstance',
                request_serializer=qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.GetUserApplicationInstanceRequest.SerializeToString,
                response_deserializer=qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.GetUserApplicationInstanceResponse.FromString,
                )
        self.DeleteUserApplicationInstance = channel.unary_unary(
                '/qwak.admiral.user_app_instance.v0.UserApplicationInstanceService/DeleteUserApplicationInstance',
                request_serializer=qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.DeleteUserApplicationInstanceRequest.SerializeToString,
                response_deserializer=qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.DeleteUserApplicationInstanceResponse.FromString,
                )


class UserApplicationInstanceServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateUserApplicationInstance(self, request, context):
        """Create new user application instance
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateUserApplicationInstanceSpec(self, request, context):
        """Update a user application instance
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserApplicationInstance(self, request, context):
        """Get a user application instance
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteUserApplicationInstance(self, request, context):
        """Delete a user application instance
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UserApplicationInstanceServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateUserApplicationInstance': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateUserApplicationInstance,
                    request_deserializer=qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.CreateUserApplicationInstanceRequest.FromString,
                    response_serializer=qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.CreateUserApplicationInstanceResponse.SerializeToString,
            ),
            'UpdateUserApplicationInstanceSpec': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateUserApplicationInstanceSpec,
                    request_deserializer=qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.UpdateUserApplicationInstanceSpecRequest.FromString,
                    response_serializer=qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.UpdateUserApplicationInstanceSpecResponse.SerializeToString,
            ),
            'GetUserApplicationInstance': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserApplicationInstance,
                    request_deserializer=qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.GetUserApplicationInstanceRequest.FromString,
                    response_serializer=qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.GetUserApplicationInstanceResponse.SerializeToString,
            ),
            'DeleteUserApplicationInstance': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteUserApplicationInstance,
                    request_deserializer=qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.DeleteUserApplicationInstanceRequest.FromString,
                    response_serializer=qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.DeleteUserApplicationInstanceResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.admiral.user_app_instance.v0.UserApplicationInstanceService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class UserApplicationInstanceService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateUserApplicationInstance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.admiral.user_app_instance.v0.UserApplicationInstanceService/CreateUserApplicationInstance',
            qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.CreateUserApplicationInstanceRequest.SerializeToString,
            qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.CreateUserApplicationInstanceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateUserApplicationInstanceSpec(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.admiral.user_app_instance.v0.UserApplicationInstanceService/UpdateUserApplicationInstanceSpec',
            qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.UpdateUserApplicationInstanceSpecRequest.SerializeToString,
            qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.UpdateUserApplicationInstanceSpecResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUserApplicationInstance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.admiral.user_app_instance.v0.UserApplicationInstanceService/GetUserApplicationInstance',
            qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.GetUserApplicationInstanceRequest.SerializeToString,
            qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.GetUserApplicationInstanceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteUserApplicationInstance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.admiral.user_app_instance.v0.UserApplicationInstanceService/DeleteUserApplicationInstance',
            qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.DeleteUserApplicationInstanceRequest.SerializeToString,
            qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.DeleteUserApplicationInstanceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
