# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/automation/v1/notification.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%qwak/automation/v1/notification.proto\x12\x12qwak.automation.v1\"\xa9\x01\n\x0cNotification\x12L\n\x17post_slack_notification\x18\x01 \x01(\x0b\x32).qwak.automation.v1.PostSlackNotificationH\x00\x12;\n\x0e\x63ustom_webhook\x18\x02 \x01(\x0b\x32!.qwak.automation.v1.CustomWebhookH\x00\x42\x0e\n\x0cnotification\"(\n\x15PostSlackNotification\x12\x0f\n\x07webhook\x18\x01 \x01(\t\"\xae\x02\n\rCustomWebhook\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x37\n\x0bhttp_method\x18\x02 \x01(\x0e\x32\".qwak.automation.v1.HttpMethodType\x12?\n\x07headers\x18\x03 \x03(\x0b\x32..qwak.automation.v1.CustomWebhook.HeadersEntry\x12\x39\n\x04\x64\x61ta\x18\x04 \x03(\x0b\x32+.qwak.automation.v1.CustomWebhook.DataEntry\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01*\xd1\x01\n\x0eHttpMethodType\x12\x1c\n\x18HTTP_METHOD_TYPE_INVALID\x10\x00\x12\x18\n\x14HTTP_METHOD_TYPE_GET\x10\x01\x12\x19\n\x15HTTP_METHOD_TYPE_POST\x10\x02\x12\x18\n\x14HTTP_METHOD_TYPE_PUT\x10\x03\x12\x1b\n\x17HTTP_METHOD_TYPE_DELETE\x10\x04\x12\x1a\n\x16HTTP_METHOD_TYPE_PATCH\x10\x05\x12\x19\n\x15HTTP_METHOD_TYPE_HEAD\x10\x06\x42!\n\x1d\x63om.qwak.ai.automation.api.v1P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.automation.v1.notification_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.qwak.ai.automation.api.v1P\001'
  _CUSTOMWEBHOOK_HEADERSENTRY._options = None
  _CUSTOMWEBHOOK_HEADERSENTRY._serialized_options = b'8\001'
  _CUSTOMWEBHOOK_DATAENTRY._options = None
  _CUSTOMWEBHOOK_DATAENTRY._serialized_options = b'8\001'
  _globals['_HTTPMETHODTYPE']._serialized_start=581
  _globals['_HTTPMETHODTYPE']._serialized_end=790
  _globals['_NOTIFICATION']._serialized_start=62
  _globals['_NOTIFICATION']._serialized_end=231
  _globals['_POSTSLACKNOTIFICATION']._serialized_start=233
  _globals['_POSTSLACKNOTIFICATION']._serialized_end=273
  _globals['_CUSTOMWEBHOOK']._serialized_start=276
  _globals['_CUSTOMWEBHOOK']._serialized_end=578
  _globals['_CUSTOMWEBHOOK_HEADERSENTRY']._serialized_start=487
  _globals['_CUSTOMWEBHOOK_HEADERSENTRY']._serialized_end=533
  _globals['_CUSTOMWEBHOOK_DATAENTRY']._serialized_start=535
  _globals['_CUSTOMWEBHOOK_DATAENTRY']._serialized_end=578
# @@protoc_insertion_point(module_scope)
