"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.vectors.v1.collection.collection_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class CreateCollectionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLLECTION_SPEC_FIELD_NUMBER: builtins.int
    @property
    def collection_spec(self) -> qwak.vectors.v1.collection.collection_pb2.VectorCollectionSpec:
        """Vector collection spec to register"""
    def __init__(
        self,
        *,
        collection_spec: qwak.vectors.v1.collection.collection_pb2.VectorCollectionSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["collection_spec", b"collection_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["collection_spec", b"collection_spec"]) -> None: ...

global___CreateCollectionRequest = CreateCollectionRequest

class CreateCollectionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VECTOR_COLLECTION_FIELD_NUMBER: builtins.int
    @property
    def vector_collection(self) -> qwak.vectors.v1.collection.collection_pb2.VectorCollection:
        """Registered vector collection"""
    def __init__(
        self,
        *,
        vector_collection: qwak.vectors.v1.collection.collection_pb2.VectorCollection | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["vector_collection", b"vector_collection"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["vector_collection", b"vector_collection"]) -> None: ...

global___CreateCollectionResponse = CreateCollectionResponse

class UpdateCollectionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLLECTION_DEFINITION_FIELD_NUMBER: builtins.int
    @property
    def collection_definition(self) -> qwak.vectors.v1.collection.collection_pb2.VectorCollectionDefinition:
        """Vector collection definition of the vector to update
        (currently supports changes only to vectorizer name and description name)
        """
    def __init__(
        self,
        *,
        collection_definition: qwak.vectors.v1.collection.collection_pb2.VectorCollectionDefinition | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["collection_definition", b"collection_definition"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["collection_definition", b"collection_definition"]) -> None: ...

global___UpdateCollectionRequest = UpdateCollectionRequest

class UpdateCollectionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VECTOR_COLLECTION_FIELD_NUMBER: builtins.int
    @property
    def vector_collection(self) -> qwak.vectors.v1.collection.collection_pb2.VectorCollection:
        """Updated vector collection"""
    def __init__(
        self,
        *,
        vector_collection: qwak.vectors.v1.collection.collection_pb2.VectorCollection | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["vector_collection", b"vector_collection"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["vector_collection", b"vector_collection"]) -> None: ...

global___UpdateCollectionResponse = UpdateCollectionResponse

class GetCollectionByIdRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Collection id to retrieve by"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___GetCollectionByIdRequest = GetCollectionByIdRequest

class GetCollectionByIdResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VECTOR_COLLECTION_FIELD_NUMBER: builtins.int
    COLLECTION_METADATA_FIELD_NUMBER: builtins.int
    @property
    def vector_collection(self) -> qwak.vectors.v1.collection.collection_pb2.VectorCollection:
        """Retrieved vector collection"""
    @property
    def collection_metadata(self) -> qwak.vectors.v1.collection.collection_pb2.CollectionMetadata:
        """Collection metadata"""
    def __init__(
        self,
        *,
        vector_collection: qwak.vectors.v1.collection.collection_pb2.VectorCollection | None = ...,
        collection_metadata: qwak.vectors.v1.collection.collection_pb2.CollectionMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["collection_metadata", b"collection_metadata", "vector_collection", b"vector_collection"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["collection_metadata", b"collection_metadata", "vector_collection", b"vector_collection"]) -> None: ...

global___GetCollectionByIdResponse = GetCollectionByIdResponse

class GetCollectionByNameRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Vector collection name to retrieve by"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___GetCollectionByNameRequest = GetCollectionByNameRequest

class GetCollectionByNameResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VECTOR_COLLECTION_FIELD_NUMBER: builtins.int
    COLLECTION_METADATA_FIELD_NUMBER: builtins.int
    @property
    def vector_collection(self) -> qwak.vectors.v1.collection.collection_pb2.VectorCollection:
        """Retrieved vector collection"""
    @property
    def collection_metadata(self) -> qwak.vectors.v1.collection.collection_pb2.CollectionMetadata:
        """Collection metadata"""
    def __init__(
        self,
        *,
        vector_collection: qwak.vectors.v1.collection.collection_pb2.VectorCollection | None = ...,
        collection_metadata: qwak.vectors.v1.collection.collection_pb2.CollectionMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["collection_metadata", b"collection_metadata", "vector_collection", b"vector_collection"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["collection_metadata", b"collection_metadata", "vector_collection", b"vector_collection"]) -> None: ...

global___GetCollectionByNameResponse = GetCollectionByNameResponse

class DeleteCollectionByIdRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Vector collection id to delete by"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___DeleteCollectionByIdRequest = DeleteCollectionByIdRequest

class DeleteCollectionByIdResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteCollectionByIdResponse = DeleteCollectionByIdResponse

class DeleteCollectionByNameRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Vector collection name to delete by"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___DeleteCollectionByNameRequest = DeleteCollectionByNameRequest

class DeleteCollectionByNameResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteCollectionByNameResponse = DeleteCollectionByNameResponse

class ListCollectionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListCollectionsRequest = ListCollectionsRequest

class ListCollectionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VECTOR_COLLECTIONS_FIELD_NUMBER: builtins.int
    @property
    def vector_collections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.vectors.v1.collection.collection_pb2.VectorCollection]:
        """Retrieved vector collections"""
    def __init__(
        self,
        *,
        vector_collections: collections.abc.Iterable[qwak.vectors.v1.collection.collection_pb2.VectorCollection] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["vector_collections", b"vector_collections"]) -> None: ...

global___ListCollectionsResponse = ListCollectionsResponse

class GetCollectionCountRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetCollectionCountRequest = GetCollectionCountRequest

class GetCollectionCountResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLLECTION_COUNT_FIELD_NUMBER: builtins.int
    collection_count: builtins.int
    def __init__(
        self,
        *,
        collection_count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["collection_count", b"collection_count"]) -> None: ...

global___GetCollectionCountResponse = GetCollectionCountResponse
