# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/kube_deployment_captain/kube_deployment_captain_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.kube_deployment_captain import alert_pb2 as qwak_dot_kube__deployment__captain_dot_alert__pb2
from _qwak_proto.qwak.kube_deployment_captain import deployment_pb2 as qwak_dot_kube__deployment__captain_dot_deployment__pb2
from _qwak_proto.qwak.kube_deployment_captain import feature_set_deployment_pb2 as qwak_dot_kube__deployment__captain_dot_feature__set__deployment__pb2
from _qwak_proto.qwak.kube_deployment_captain import batch_job_pb2 as qwak_dot_kube__deployment__captain_dot_batch__job__pb2
from _qwak_proto.qwak.kube_deployment_captain import traffic_mapping_pb2 as qwak_dot_kube__deployment__captain_dot_traffic__mapping__pb2
from _qwak_proto.qwak.kube_deployment_captain import alerting_pb2 as qwak_dot_kube__deployment__captain_dot_alerting__pb2
from _qwak_proto.qwak.execution.v1 import backfill_pb2 as qwak_dot_execution_dot_v1_dot_backfill__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBqwak/kube_deployment_captain/kube_deployment_captain_service.proto\x12\x1cqwak.kube.deployment.captain\x1a(qwak/kube_deployment_captain/alert.proto\x1a-qwak/kube_deployment_captain/deployment.proto\x1a\x39qwak/kube_deployment_captain/feature_set_deployment.proto\x1a,qwak/kube_deployment_captain/batch_job.proto\x1a\x32qwak/kube_deployment_captain/traffic_mapping.proto\x1a+qwak/kube_deployment_captain/alerting.proto\x1a qwak/execution/v1/backfill.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe4\x01\n\x18\x41pplyModelsAlertsRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12;\n\x06\x61lerts\x18\x03 \x03(\x0b\x32+.qwak.kube.deployment.captain.KubeAlertRule\x12N\n\x14kube_deployment_type\x18\x04 \x01(\x0e\x32\x30.qwak.kube.deployment.captain.KubeDeploymentType\x12\x12\n\nmodel_link\x18\x05 \x01(\t\"n\n%CreateOrReplaceFeatureSetAlertRequest\x12\x45\n\x07options\x18\x01 \x01(\x0b\x32\x34.qwak.kube.deployment.captain.FeatureSetAlertOptions\"e\n\x1c\x44\x65leteFeatureSetAlertRequest\x12\x45\n\x07options\x18\x01 \x01(\x0b\x32\x34.qwak.kube.deployment.captain.FeatureSetAlertOptions\"\x1f\n\x1d\x44\x65leteFeatureSetAlertResponse\"*\n(CreateOrReplaceFeatureSetFailureResponse\"\x1b\n\x19\x41pplyModelsAlertsResponse\"U\n*CleanStorageObjectFromCloudStorageResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x16\n\x0e\x66\x61ilure_reason\x18\x02 \x01(\t\"\xcf\x05\n\x16KubeDeployModelRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12\x10\n\x08\x62uild_id\x18\x03 \x01(\t\x12\x14\n\x0c\x64ocker_image\x18\x04 \x01(\t\x12\x1a\n\x0enumber_of_pods\x18\x05 \x01(\x05\x42\x02\x18\x01\x12I\n\x0f\x64\x65ployment_size\x18\x06 \x01(\x0b\x32\x30.qwak.kube.deployment.captain.KubeDeploymentSize\x12`\n\x1b\x61\x64vanced_deployment_options\x18\x07 \x01(\x0b\x32;.qwak.kube.deployment.captain.KubeAdvancedDeploymentOptions\x12\x15\n\rdeployment_id\x18\x08 \x01(\t\x12K\n\x10serving_strategy\x18\t \x01(\x0b\x32\x31.qwak.kube.deployment.captain.KubeServingStrategy\x12m\n\x15\x65nvironment_variables\x18\n \x03(\x0b\x32N.qwak.kube.deployment.captain.KubeDeployModelRequest.EnvironmentVariablesEntry\x12H\n\x11\x61uto_scaling_spec\x18\x0b \x01(\x0b\x32-.qwak.kube.deployment.captain.AutoScalingSpec\x12\x12\n\nmodel_uuid\x18\x0c \x01(\t\x12\x12\n\nproject_id\x18\r \x01(\t\x12\x19\n\x11image_pull_secret\x18\x0e \x01(\t\x1a;\n\x19\x45nvironmentVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x19\n\x17KubeDeployModelResponse\"\xc6\x01\n!RevertFailedKubeDeploymentRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12\x10\n\x08\x62uild_id\x18\x03 \x01(\t\x12N\n\x14kube_deployment_type\x18\x04 \x01(\x0e\x32\x30.qwak.kube.deployment.captain.KubeDeploymentType\x12\x16\n\x0evariation_name\x18\x05 \x01(\t\"$\n\"RevertFailedKubeDeploymentResponse\"\x97\x02\n*UpdateKubeDeploymentRuntimeSettingsRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12X\n\x13\x64\x65ployment_settings\x18\x03 \x01(\x0b\x32;.qwak.kube.deployment.captain.KubeRuntimeDeploymentSettings\x12N\n\x14kube_deployment_type\x18\x04 \x01(\x0e\x32\x30.qwak.kube.deployment.captain.KubeDeploymentType\x12\x16\n\x0evariation_name\x18\x05 \x01(\t\"-\n+UpdateKubeDeploymentRuntimeSettingsResponse\"\xbc\x01\n\x18KubeUndeployModelRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12N\n\x14kube_deployment_type\x18\x02 \x01(\x0e\x32\x30.qwak.kube.deployment.captain.KubeDeploymentType\x12\'\n\x1fselected_variation_mapping_name\x18\x03 \x01(\t\x12\x15\n\rlast_undeploy\x18\x04 \x01(\x08\"\x1b\n\x19KubeUndeployModelResponse\"\xb6\x01\n#GetKubeModelDeploymentStatusRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\rdeployment_id\x18\x02 \x01(\t\x12N\n\x14kube_deployment_type\x18\x03 \x01(\x0e\x32\x30.qwak.kube.deployment.captain.KubeDeploymentType\x12\x16\n\x0evariation_name\x18\x04 \x01(\t\"\xa7\x01\n$GetKubeModelDeploymentStatusResponse\x12G\n\x06status\x18\x01 \x01(\x0e\x32\x37.qwak.kube.deployment.captain.KubeModelDeploymentStatus\x12\x1b\n\x13\x66\x61ilure_reason_code\x18\x02 \x01(\t\x12\x19\n\x11technical_details\x18\x03 \x01(\t\"w\n ApplyNotificationsChannelRequest\x12S\n\x14notification_channel\x18\x01 \x01(\x0b\x32\x35.qwak.kube.deployment.captain.KubeNotificationChannel\"\"\n ApplyNotificationChannelResponse\"C\n DeleteNotificationChannelRequest\x12\x1f\n\x17notification_channel_id\x18\x01 \x01(\t\"#\n!DeleteNotificationChannelResponse\"k\n\x17\x44\x65ployFeatureSetRequest\x12P\n\x10\x66\x65\x61ture_set_spec\x18\x01 \x01(\x0b\x32\x36.qwak.kube.deployment.captain.FeatureSetDeploymentSpec\"\x1a\n\x18\x44\x65ployFeatureSetResponse\"\x97\x01\n)DeployStreamingAggregationBackfillRequest\x12R\n\x16\x66\x65\x61ture_set_deployment\x18\x01 \x01(\x0b\x32\x32.qwak.kube.deployment.captain.FeatureSetDeployment\x12\x16\n\x0e\x65nvironment_id\x18\x02 \x01(\t\"\xb1\x02\n\"BatchFeatureSetV1DeploymentRequest\x12R\n\x16\x66\x65\x61ture_set_deployment\x18\x01 \x01(\x0b\x32\x32.qwak.kube.deployment.captain.FeatureSetDeployment\x12\x41\n\rbatch_details\x18\x02 \x01(\x0b\x32*.qwak.kube.deployment.captain.BatchDetails\x12\x16\n\x0e\x65nvironment_id\x18\x03 \x01(\t\x12Q\n\x14\x65xecution_identifier\x18\x04 \x01(\x0b\x32\x31.qwak.kube.deployment.captain.ExecutionIdentifierH\x00\x42\t\n\x07\x65xec_id\"\xe4\x02\n\x1a\x44\x65ployBatchBackfillRequest\x12R\n\x16\x66\x65\x61ture_set_deployment\x18\x01 \x01(\x0b\x32\x32.qwak.kube.deployment.captain.FeatureSetDeployment\x12\x44\n\rbackfill_spec\x18\x02 \x01(\x0b\x32-.qwak.feature.store.execution.v1.BackfillSpec\x12\x16\n\x0e\x65nvironment_id\x18\x03 \x01(\t\x12O\n\x14\x65xecution_identifier\x18\x04 \x01(\x0b\x32\x31.qwak.kube.deployment.captain.ExecutionIdentifier\x12\x43\n\x1flast_known_batch_execution_date\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x1d\n\x1b\x44\x65ployBatchBackfillResponse\"7\n\x1cUndeployBatchBackfillRequest\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x01 \x01(\t\"\x1f\n\x1dUndeployBatchBackfillResponse\"\x8c\x01\n\x1e\x44\x65leteBatchFeatureSetV1Request\x12R\n\x16\x66\x65\x61ture_set_deployment\x18\x01 \x01(\x0b\x32\x32.qwak.kube.deployment.captain.FeatureSetDeployment\x12\x16\n\x0e\x65nvironment_id\x18\x02 \x01(\t\"!\n\x1f\x44\x65leteBatchFeatureSetV1Response\"\x90\x01\n\"DeleteStreamingFeatureSetV1Request\x12R\n\x16\x66\x65\x61ture_set_deployment\x18\x01 \x01(\x0b\x32\x32.qwak.kube.deployment.captain.FeatureSetDeployment\x12\x16\n\x0e\x65nvironment_id\x18\x02 \x01(\t\"%\n#DeleteStreamingFeatureSetV1Response\"\x99\x01\n+DeleteStreamingAggregationFeatureSetRequest\x12R\n\x16\x66\x65\x61ture_set_deployment\x18\x01 \x01(\x0b\x32\x32.qwak.kube.deployment.captain.FeatureSetDeployment\x12\x16\n\x0e\x65nvironment_id\x18\x02 \x01(\t\".\n,DeleteStreamingAggregationFeatureSetResponse\"\x99\x01\n+DeployStreamingAggregationCompactionRequest\x12R\n\x16\x66\x65\x61ture_set_deployment\x18\x01 \x01(\x0b\x32\x32.qwak.kube.deployment.captain.FeatureSetDeployment\x12\x16\n\x0e\x65nvironment_id\x18\x02 \x01(\t\"\x7f\n)DeployStreamingAggregationRowLevelRequest\x12R\n\x16\x66\x65\x61ture_set_deployment\x18\x01 \x01(\x0b\x32\x32.qwak.kube.deployment.captain.FeatureSetDeployment\"\x94\x01\n&StreamingFeatureSetV1DeploymentRequest\x12R\n\x16\x66\x65\x61ture_set_deployment\x18\x01 \x01(\x0b\x32\x32.qwak.kube.deployment.captain.FeatureSetDeployment\x12\x16\n\x0e\x65nvironment_id\x18\x02 \x01(\t\",\n*DeployStreamingAggregationBackfillResponse\",\n*DeployStreamingAggregationRowLevelResponse\".\n,DeployStreamingAggregationCompactionResponse\"5\n\x19UndeployFeatureSetRequest\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x01 \x01(\t\"\x1c\n\x1aUndeployFeatureSetResponse\"9\n\x1eUndeployBatchFeaturesetRequest\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x01 \x01(\t\"!\n\x1fUndeployBatchFeaturesetResponse\"\x7f\n\x1f\x41pplyModelTrafficMappingRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12J\n\x12variation_mappings\x18\x02 \x03(\x0b\x32..qwak.kube.deployment.captain.VariationMapping\"\"\n ApplyModelTrafficMappingResponse\"\xaf\x01\n\x1cRevertModelDeploymentRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x16\n\x0evariation_name\x18\x02 \x01(\t\x12N\n\x14kube_deployment_type\x18\x03 \x01(\x0e\x32\x30.qwak.kube.deployment.captain.KubeDeploymentType\x12\x15\n\rdeployment_id\x18\x04 \x01(\t\"\x1f\n\x1dRevertModelDeploymentResponse*\xaf\x01\n\x19KubeModelDeploymentStatus\x12\x12\n\x0eINVALID_STATUS\x10\x00\x12\x16\n\x12PENDING_DEPLOYMENT\x10\x02\x12\x19\n\x15SUCCESSFUL_DEPLOYMENT\x10\x03\x12\x15\n\x11\x46\x41ILED_DEPLOYMENT\x10\x04\x12\x1b\n\x17SUCCESSFUL_UNDEPLOYMENT\x10\x05\x12\x17\n\x13\x46\x41ILED_UNDEPLOYMENT\x10\x06\x32\xdd+\n\x15KubeDeploymentCaptain\x12~\n\x0fKubeDeployModel\x12\x34.qwak.kube.deployment.captain.KubeDeployModelRequest\x1a\x35.qwak.kube.deployment.captain.KubeDeployModelResponse\x12\x84\x01\n\x11KubeUndeployModel\x12\x36.qwak.kube.deployment.captain.KubeUndeployModelRequest\x1a\x37.qwak.kube.deployment.captain.KubeUndeployModelResponse\x12\x9e\x01\n\x18\x41pplyModelTrafficMapping\x12=.qwak.kube.deployment.captain.ApplyModelTrafficMappingRequest\x1a>.qwak.kube.deployment.captain.ApplyModelTrafficMappingResponse\"\x03\x88\x02\x01\x12\xa5\x01\n\x1cGetKubeModelDeploymentStatus\x12\x41.qwak.kube.deployment.captain.GetKubeModelDeploymentStatusRequest\x1a\x42.qwak.kube.deployment.captain.GetKubeModelDeploymentStatusResponse\x12\x9f\x01\n\x1aRevertFailedKubeDeployment\x12?.qwak.kube.deployment.captain.RevertFailedKubeDeploymentRequest\x1a@.qwak.kube.deployment.captain.RevertFailedKubeDeploymentResponse\x12\xba\x01\n#UpdateKubeDeploymentRuntimeSettings\x12H.qwak.kube.deployment.captain.UpdateKubeDeploymentRuntimeSettingsRequest\x1aI.qwak.kube.deployment.captain.UpdateKubeDeploymentRuntimeSettingsResponse\x12\x84\x01\n\x11\x41pplyModelsAlerts\x12\x36.qwak.kube.deployment.captain.ApplyModelsAlertsRequest\x1a\x37.qwak.kube.deployment.captain.ApplyModelsAlertsResponse\x12\x9a\x01\n\x18\x41pplyNotificationChannel\x12>.qwak.kube.deployment.captain.ApplyNotificationsChannelRequest\x1a>.qwak.kube.deployment.captain.ApplyNotificationChannelResponse\x12\x9c\x01\n\x19\x44\x65leteNotificationChannel\x12>.qwak.kube.deployment.captain.DeleteNotificationChannelRequest\x1a?.qwak.kube.deployment.captain.DeleteNotificationChannelResponse\x12\x8a\x01\n\x19\x44\x65ployFeatureSetProcessor\x12\x35.qwak.kube.deployment.captain.DeployFeatureSetRequest\x1a\x36.qwak.kube.deployment.captain.DeployFeatureSetResponse\x12\x9b\x01\n\x1b\x44\x65ployStreamingFeatureSetV1\x12\x44.qwak.kube.deployment.captain.StreamingFeatureSetV1DeploymentRequest\x1a\x36.qwak.kube.deployment.captain.DeployFeatureSetResponse\x12\xa1\x01\n!DeployStreamingOnlineFeatureSetV1\x12\x44.qwak.kube.deployment.captain.StreamingFeatureSetV1DeploymentRequest\x1a\x36.qwak.kube.deployment.captain.DeployFeatureSetResponse\x12\xa2\x01\n\"DeployStreamingOfflineFeatureSetV1\x12\x44.qwak.kube.deployment.captain.StreamingFeatureSetV1DeploymentRequest\x1a\x36.qwak.kube.deployment.captain.DeployFeatureSetResponse\x12\x93\x01\n\x17\x44\x65ployBatchFeatureSetV1\x12@.qwak.kube.deployment.captain.BatchFeatureSetV1DeploymentRequest\x1a\x36.qwak.kube.deployment.captain.DeployFeatureSetResponse\x12\x87\x01\n\x12UndeployFeatureSet\x12\x37.qwak.kube.deployment.captain.UndeployFeatureSetRequest\x1a\x38.qwak.kube.deployment.captain.UndeployFeatureSetResponse\x12\x96\x01\n\x17UndeployBatchFeatureset\x12<.qwak.kube.deployment.captain.UndeployBatchFeaturesetRequest\x1a=.qwak.kube.deployment.captain.UndeployBatchFeaturesetResponse\x12\x90\x01\n\x15ListInferenceJobFiles\x12:.qwak.kube.deployment.captain.ListInferenceJobFilesRequest\x1a;.qwak.kube.deployment.captain.ListInferenceJobFilesResponse\x12\xa3\x01\n\x1c\x43reateInferenceTaskExecution\x12@.qwak.kube.deployment.captain.CreateInferenceTaskExecutorRequest\x1a\x41.qwak.kube.deployment.captain.CreateInferenceTaskExecutorResponse\x12\xa5\x01\n\x1c\x43leanInferenceTasksExecutors\x12\x41.qwak.kube.deployment.captain.CleanInferenceTasksExecutorsRequest\x1a\x42.qwak.kube.deployment.captain.CleanInferenceTasksExecutorsResponse\x12\x9f\x01\n\x1a\x43leanInferenceTaskExecutor\x12?.qwak.kube.deployment.captain.CleanInferenceTaskExecutorRequest\x1a@.qwak.kube.deployment.captain.CleanInferenceTaskExecutorResponse\x12\x96\x01\n\x17StartInferenceJobWarmup\x12<.qwak.kube.deployment.captain.StartInferenceJobWarmupRequest\x1a=.qwak.kube.deployment.captain.StartInferenceJobWarmupResponse\x12\x99\x01\n\x18\x43\x61ncelInferenceJobWarmup\x12=.qwak.kube.deployment.captain.CancelInferenceJobWarmupRequest\x1a>.qwak.kube.deployment.captain.CancelInferenceJobWarmupResponse\x12\x8a\x01\n\x13PrepareInferenceJob\x12\x38.qwak.kube.deployment.captain.PrepareInferenceJobRequest\x1a\x39.qwak.kube.deployment.captain.PrepareInferenceJobResponse\x12\xad\x01\n\x1e\x43reateOrReplaceFeatureSetAlert\x12\x43.qwak.kube.deployment.captain.CreateOrReplaceFeatureSetAlertRequest\x1a\x46.qwak.kube.deployment.captain.CreateOrReplaceFeatureSetFailureResponse\x12\x90\x01\n\x15\x44\x65leteFeatureSetAlert\x12:.qwak.kube.deployment.captain.DeleteFeatureSetAlertRequest\x1a;.qwak.kube.deployment.captain.DeleteFeatureSetAlertResponse\x12\xb7\x01\n\"DeployStreamingAggregationBackfill\x12G.qwak.kube.deployment.captain.DeployStreamingAggregationBackfillRequest\x1aH.qwak.kube.deployment.captain.DeployStreamingAggregationBackfillResponse\x12\xbd\x01\n$DeployStreamingAggregationCompaction\x12I.qwak.kube.deployment.captain.DeployStreamingAggregationCompactionRequest\x1aJ.qwak.kube.deployment.captain.DeployStreamingAggregationCompactionResponse\x12\xb7\x01\n\"DeployStreamingAggregationRowLevel\x12G.qwak.kube.deployment.captain.DeployStreamingAggregationRowLevelRequest\x1aH.qwak.kube.deployment.captain.DeployStreamingAggregationRowLevelResponse\x12\x96\x01\n\x17\x44\x65leteBatchFeaturesetV1\x12<.qwak.kube.deployment.captain.DeleteBatchFeatureSetV1Request\x1a=.qwak.kube.deployment.captain.DeleteBatchFeatureSetV1Response\x12\xa2\x01\n\x1b\x44\x65leteStreamingFeatureSetV1\x12@.qwak.kube.deployment.captain.DeleteStreamingFeatureSetV1Request\x1a\x41.qwak.kube.deployment.captain.DeleteStreamingFeatureSetV1Response\x12\xbd\x01\n$DeleteStreamingAggregationFeatureSet\x12I.qwak.kube.deployment.captain.DeleteStreamingAggregationFeatureSetRequest\x1aJ.qwak.kube.deployment.captain.DeleteStreamingAggregationFeatureSetResponse\x12\x8a\x01\n\x13\x44\x65ployBatchBackfill\x12\x38.qwak.kube.deployment.captain.DeployBatchBackfillRequest\x1a\x39.qwak.kube.deployment.captain.DeployBatchBackfillResponse\x12\x90\x01\n\x15UndeployBatchBackfill\x12:.qwak.kube.deployment.captain.UndeployBatchBackfillRequest\x1a;.qwak.kube.deployment.captain.UndeployBatchBackfillResponse\x12\x90\x01\n\x15RevertModelDeployment\x12:.qwak.kube.deployment.captain.RevertModelDeploymentRequest\x1a;.qwak.kube.deployment.captain.RevertModelDeploymentResponse\x12\xb7\x01\n\"CleanStorageObjectFromCloudStorage\x12G.qwak.kube.deployment.captain.CleanStorageObjectFromCloudStorageRequest\x1aH.qwak.kube.deployment.captain.CleanStorageObjectFromCloudStorageResponseB+\n\'com.qwak.ai.kube.deployment.captain.apiP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.kube_deployment_captain.kube_deployment_captain_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\'com.qwak.ai.kube.deployment.captain.apiP\001'
  _APPLYMODELSALERTSREQUEST.fields_by_name['branch_id']._options = None
  _APPLYMODELSALERTSREQUEST.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _KUBEDEPLOYMODELREQUEST_ENVIRONMENTVARIABLESENTRY._options = None
  _KUBEDEPLOYMODELREQUEST_ENVIRONMENTVARIABLESENTRY._serialized_options = b'8\001'
  _KUBEDEPLOYMODELREQUEST.fields_by_name['branch_id']._options = None
  _KUBEDEPLOYMODELREQUEST.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _KUBEDEPLOYMODELREQUEST.fields_by_name['number_of_pods']._options = None
  _KUBEDEPLOYMODELREQUEST.fields_by_name['number_of_pods']._serialized_options = b'\030\001'
  _REVERTFAILEDKUBEDEPLOYMENTREQUEST.fields_by_name['branch_id']._options = None
  _REVERTFAILEDKUBEDEPLOYMENTREQUEST.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _UPDATEKUBEDEPLOYMENTRUNTIMESETTINGSREQUEST.fields_by_name['branch_id']._options = None
  _UPDATEKUBEDEPLOYMENTRUNTIMESETTINGSREQUEST.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _KUBEDEPLOYMENTCAPTAIN.methods_by_name['ApplyModelTrafficMapping']._options = None
  _KUBEDEPLOYMENTCAPTAIN.methods_by_name['ApplyModelTrafficMapping']._serialized_options = b'\210\002\001'
  _globals['_KUBEMODELDEPLOYMENTSTATUS']._serialized_start=6031
  _globals['_KUBEMODELDEPLOYMENTSTATUS']._serialized_end=6206
  _globals['_APPLYMODELSALERTSREQUEST']._serialized_start=459
  _globals['_APPLYMODELSALERTSREQUEST']._serialized_end=687
  _globals['_CREATEORREPLACEFEATURESETALERTREQUEST']._serialized_start=689
  _globals['_CREATEORREPLACEFEATURESETALERTREQUEST']._serialized_end=799
  _globals['_DELETEFEATURESETALERTREQUEST']._serialized_start=801
  _globals['_DELETEFEATURESETALERTREQUEST']._serialized_end=902
  _globals['_DELETEFEATURESETALERTRESPONSE']._serialized_start=904
  _globals['_DELETEFEATURESETALERTRESPONSE']._serialized_end=935
  _globals['_CREATEORREPLACEFEATURESETFAILURERESPONSE']._serialized_start=937
  _globals['_CREATEORREPLACEFEATURESETFAILURERESPONSE']._serialized_end=979
  _globals['_APPLYMODELSALERTSRESPONSE']._serialized_start=981
  _globals['_APPLYMODELSALERTSRESPONSE']._serialized_end=1008
  _globals['_CLEANSTORAGEOBJECTFROMCLOUDSTORAGERESPONSE']._serialized_start=1010
  _globals['_CLEANSTORAGEOBJECTFROMCLOUDSTORAGERESPONSE']._serialized_end=1095
  _globals['_KUBEDEPLOYMODELREQUEST']._serialized_start=1098
  _globals['_KUBEDEPLOYMODELREQUEST']._serialized_end=1817
  _globals['_KUBEDEPLOYMODELREQUEST_ENVIRONMENTVARIABLESENTRY']._serialized_start=1758
  _globals['_KUBEDEPLOYMODELREQUEST_ENVIRONMENTVARIABLESENTRY']._serialized_end=1817
  _globals['_KUBEDEPLOYMODELRESPONSE']._serialized_start=1819
  _globals['_KUBEDEPLOYMODELRESPONSE']._serialized_end=1844
  _globals['_REVERTFAILEDKUBEDEPLOYMENTREQUEST']._serialized_start=1847
  _globals['_REVERTFAILEDKUBEDEPLOYMENTREQUEST']._serialized_end=2045
  _globals['_REVERTFAILEDKUBEDEPLOYMENTRESPONSE']._serialized_start=2047
  _globals['_REVERTFAILEDKUBEDEPLOYMENTRESPONSE']._serialized_end=2083
  _globals['_UPDATEKUBEDEPLOYMENTRUNTIMESETTINGSREQUEST']._serialized_start=2086
  _globals['_UPDATEKUBEDEPLOYMENTRUNTIMESETTINGSREQUEST']._serialized_end=2365
  _globals['_UPDATEKUBEDEPLOYMENTRUNTIMESETTINGSRESPONSE']._serialized_start=2367
  _globals['_UPDATEKUBEDEPLOYMENTRUNTIMESETTINGSRESPONSE']._serialized_end=2412
  _globals['_KUBEUNDEPLOYMODELREQUEST']._serialized_start=2415
  _globals['_KUBEUNDEPLOYMODELREQUEST']._serialized_end=2603
  _globals['_KUBEUNDEPLOYMODELRESPONSE']._serialized_start=2605
  _globals['_KUBEUNDEPLOYMODELRESPONSE']._serialized_end=2632
  _globals['_GETKUBEMODELDEPLOYMENTSTATUSREQUEST']._serialized_start=2635
  _globals['_GETKUBEMODELDEPLOYMENTSTATUSREQUEST']._serialized_end=2817
  _globals['_GETKUBEMODELDEPLOYMENTSTATUSRESPONSE']._serialized_start=2820
  _globals['_GETKUBEMODELDEPLOYMENTSTATUSRESPONSE']._serialized_end=2987
  _globals['_APPLYNOTIFICATIONSCHANNELREQUEST']._serialized_start=2989
  _globals['_APPLYNOTIFICATIONSCHANNELREQUEST']._serialized_end=3108
  _globals['_APPLYNOTIFICATIONCHANNELRESPONSE']._serialized_start=3110
  _globals['_APPLYNOTIFICATIONCHANNELRESPONSE']._serialized_end=3144
  _globals['_DELETENOTIFICATIONCHANNELREQUEST']._serialized_start=3146
  _globals['_DELETENOTIFICATIONCHANNELREQUEST']._serialized_end=3213
  _globals['_DELETENOTIFICATIONCHANNELRESPONSE']._serialized_start=3215
  _globals['_DELETENOTIFICATIONCHANNELRESPONSE']._serialized_end=3250
  _globals['_DEPLOYFEATURESETREQUEST']._serialized_start=3252
  _globals['_DEPLOYFEATURESETREQUEST']._serialized_end=3359
  _globals['_DEPLOYFEATURESETRESPONSE']._serialized_start=3361
  _globals['_DEPLOYFEATURESETRESPONSE']._serialized_end=3387
  _globals['_DEPLOYSTREAMINGAGGREGATIONBACKFILLREQUEST']._serialized_start=3390
  _globals['_DEPLOYSTREAMINGAGGREGATIONBACKFILLREQUEST']._serialized_end=3541
  _globals['_BATCHFEATURESETV1DEPLOYMENTREQUEST']._serialized_start=3544
  _globals['_BATCHFEATURESETV1DEPLOYMENTREQUEST']._serialized_end=3849
  _globals['_DEPLOYBATCHBACKFILLREQUEST']._serialized_start=3852
  _globals['_DEPLOYBATCHBACKFILLREQUEST']._serialized_end=4208
  _globals['_DEPLOYBATCHBACKFILLRESPONSE']._serialized_start=4210
  _globals['_DEPLOYBATCHBACKFILLRESPONSE']._serialized_end=4239
  _globals['_UNDEPLOYBATCHBACKFILLREQUEST']._serialized_start=4241
  _globals['_UNDEPLOYBATCHBACKFILLREQUEST']._serialized_end=4296
  _globals['_UNDEPLOYBATCHBACKFILLRESPONSE']._serialized_start=4298
  _globals['_UNDEPLOYBATCHBACKFILLRESPONSE']._serialized_end=4329
  _globals['_DELETEBATCHFEATURESETV1REQUEST']._serialized_start=4332
  _globals['_DELETEBATCHFEATURESETV1REQUEST']._serialized_end=4472
  _globals['_DELETEBATCHFEATURESETV1RESPONSE']._serialized_start=4474
  _globals['_DELETEBATCHFEATURESETV1RESPONSE']._serialized_end=4507
  _globals['_DELETESTREAMINGFEATURESETV1REQUEST']._serialized_start=4510
  _globals['_DELETESTREAMINGFEATURESETV1REQUEST']._serialized_end=4654
  _globals['_DELETESTREAMINGFEATURESETV1RESPONSE']._serialized_start=4656
  _globals['_DELETESTREAMINGFEATURESETV1RESPONSE']._serialized_end=4693
  _globals['_DELETESTREAMINGAGGREGATIONFEATURESETREQUEST']._serialized_start=4696
  _globals['_DELETESTREAMINGAGGREGATIONFEATURESETREQUEST']._serialized_end=4849
  _globals['_DELETESTREAMINGAGGREGATIONFEATURESETRESPONSE']._serialized_start=4851
  _globals['_DELETESTREAMINGAGGREGATIONFEATURESETRESPONSE']._serialized_end=4897
  _globals['_DEPLOYSTREAMINGAGGREGATIONCOMPACTIONREQUEST']._serialized_start=4900
  _globals['_DEPLOYSTREAMINGAGGREGATIONCOMPACTIONREQUEST']._serialized_end=5053
  _globals['_DEPLOYSTREAMINGAGGREGATIONROWLEVELREQUEST']._serialized_start=5055
  _globals['_DEPLOYSTREAMINGAGGREGATIONROWLEVELREQUEST']._serialized_end=5182
  _globals['_STREAMINGFEATURESETV1DEPLOYMENTREQUEST']._serialized_start=5185
  _globals['_STREAMINGFEATURESETV1DEPLOYMENTREQUEST']._serialized_end=5333
  _globals['_DEPLOYSTREAMINGAGGREGATIONBACKFILLRESPONSE']._serialized_start=5335
  _globals['_DEPLOYSTREAMINGAGGREGATIONBACKFILLRESPONSE']._serialized_end=5379
  _globals['_DEPLOYSTREAMINGAGGREGATIONROWLEVELRESPONSE']._serialized_start=5381
  _globals['_DEPLOYSTREAMINGAGGREGATIONROWLEVELRESPONSE']._serialized_end=5425
  _globals['_DEPLOYSTREAMINGAGGREGATIONCOMPACTIONRESPONSE']._serialized_start=5427
  _globals['_DEPLOYSTREAMINGAGGREGATIONCOMPACTIONRESPONSE']._serialized_end=5473
  _globals['_UNDEPLOYFEATURESETREQUEST']._serialized_start=5475
  _globals['_UNDEPLOYFEATURESETREQUEST']._serialized_end=5528
  _globals['_UNDEPLOYFEATURESETRESPONSE']._serialized_start=5530
  _globals['_UNDEPLOYFEATURESETRESPONSE']._serialized_end=5558
  _globals['_UNDEPLOYBATCHFEATURESETREQUEST']._serialized_start=5560
  _globals['_UNDEPLOYBATCHFEATURESETREQUEST']._serialized_end=5617
  _globals['_UNDEPLOYBATCHFEATURESETRESPONSE']._serialized_start=5619
  _globals['_UNDEPLOYBATCHFEATURESETRESPONSE']._serialized_end=5652
  _globals['_APPLYMODELTRAFFICMAPPINGREQUEST']._serialized_start=5654
  _globals['_APPLYMODELTRAFFICMAPPINGREQUEST']._serialized_end=5781
  _globals['_APPLYMODELTRAFFICMAPPINGRESPONSE']._serialized_start=5783
  _globals['_APPLYMODELTRAFFICMAPPINGRESPONSE']._serialized_end=5817
  _globals['_REVERTMODELDEPLOYMENTREQUEST']._serialized_start=5820
  _globals['_REVERTMODELDEPLOYMENTREQUEST']._serialized_end=5995
  _globals['_REVERTMODELDEPLOYMENTRESPONSE']._serialized_start=5997
  _globals['_REVERTMODELDEPLOYMENTRESPONSE']._serialized_end=6028
  _globals['_KUBEDEPLOYMENTCAPTAIN']._serialized_start=6209
  _globals['_KUBEDEPLOYMENTCAPTAIN']._serialized_end=11806
# @@protoc_insertion_point(module_scope)
